==> goods-center-api-2.1.17-xt2-20170828.084145-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/AppItemClassifyDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2016/11/17.
 */
public class AppItemClassifyDto implements Serializable{

    private static final long serialVersionUID = 7315954292452708898L;

    private Long id;

    private Long appId;

    private String name;

    private Boolean deleted;

    private Date gmtCreate;

    private Date gmtModified;

    private Integer appItemNum;

    private String image;

    private String classifyImage;//分类列表表头图片

    private Boolean classifyImageSwitch;//分类列表表头图片显示开关

    public Integer getAppItemNum() {
        return appItemNum;
    }

    public void setAppItemNum(Integer appItemNum) {
        this.appItemNum = appItemNum;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getClassifyImage() {
        return classifyImage;
    }

    public void setClassifyImage(String classifyImage) {
        this.classifyImage = classifyImage;
    }

    public Boolean getClassifyImageSwitch() {
        return classifyImageSwitch;
    }

    public void setClassifyImageSwitch(Boolean classifyImageSwitch) {
        this.classifyImageSwitch = classifyImageSwitch;
    }
}

==> goods-center-api-2.3.16-xt-20180205.130909-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/AppItemClassifyDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2016/11/17.
 */
public class AppItemClassifyDto implements Serializable{

    public static int              ITEM_TOP_START    = 1000000;            // 置顶项的起始权重,来自DevCustomManagerImpl

    public static int              ITEM_TOP_NUM      = 3;                  // 每个APP可以置顶数目,来自DevCustomManagerImpl

    private static final long serialVersionUID = 7315954292452708898L;

    private Long id;

    private Long appId;

    private String name;

    private Boolean deleted;

    private Date gmtCreate;

    private Date gmtModified;

    private Integer appItemNum;

    private String image;

    private String classifyImage;//分类列表表头图片

    private Boolean classifyImageSwitch;//分类列表表头图片显示开关

    public Integer getAppItemNum() {
        return appItemNum;
    }

    public void setAppItemNum(Integer appItemNum) {
        this.appItemNum = appItemNum;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(Boolean deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getClassifyImage() {
        return classifyImage;
    }

    public void setClassifyImage(String classifyImage) {
        this.classifyImage = classifyImage;
    }

    public Boolean getClassifyImageSwitch() {
        return classifyImageSwitch;
    }

    public void setClassifyImageSwitch(Boolean classifyImageSwitch) {
        this.classifyImageSwitch = classifyImageSwitch;
    }
}
